/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.karaf.diagnostic.core.internal;

import java.io.Closeable;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

public class Activator implements BundleActivator {
    Closeable dumpHandler;

    public void start(BundleContext context) throws Exception {
        if (!isWindows()) {
            ClassLoader cl = this.getClass().getClassLoader();
            try {
                Class<?> dumpHandlerClazz = cl.loadClass("org.apache.karaf.diagnostic.core.internal.DumpHandler");
                dumpHandler = (Closeable) dumpHandlerClazz.getConstructor(BundleContext.class).newInstance(context);
            } catch (Throwable e) {
                // Will happen if sun.misc.SignalHandler is not available
            }
        }
    }

    public void stop(BundleContext context) throws Exception {
        if (dumpHandler != null && !isWindows()) {
            dumpHandler.close();
        }
    }

    private boolean isWindows() {
        return System.getProperty("os.name", "Unknown").startsWith("Win");
    }

}
